@@ -15,7 +15,7 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: Node.pm,v 1.1.1.1 2000/11/17 17:31:53 abw Exp $
+#   $Id: Node.pm,v 1.1.1.1 2001/05/17 08:49:34 abw Exp $
 #
 #========================================================================
 
@@ -34,6 +34,8 @@ $NODES   = {
     pod      => 'Pod::POM::Node::Pod',
     head1    => 'Pod::POM::Node::Head1',
     head2    => 'Pod::POM::Node::Head2',
+    head3    => 'Pod::POM::Node::Head3',
+    head4    => 'Pod::POM::Node::Head4',
     over     => 'Pod::POM::Node::Over',
     item     => 'Pod::POM::Node::Item',
     begin    => 'Pod::POM::Node::Begin',
@@ -49,6 +51,9 @@ $NAMES = {
 # overload stringification to present node via a view
 use overload '""' => 'present';
 
+# alias meta() to metadata()
+*meta = \*metadata;
+
 
 #------------------------------------------------------------------------
 # new($pom, @attr)
@@ -173,11 +178,38 @@ sub present {
     $view    ||= $Pod::POM::DEFAULT_VIEW;
     my $type   = $self->{ type };
     my $method = "view_$type";
-
+    DEBUG("presenting method $method\n");
     return $view->$method($self);
 }
 
 
+#------------------------------------------------------------------------
+# metadata()
+# metadata($key)
+# metadata($key, $value)
+#
+# Returns the metadata hash when called without any arguments.  Returns
+# the value of a metadata item when called with a single argument.  
+# Sets a metadata item to a value when called with two arguments.
+#------------------------------------------------------------------------
+
+sub metadata {
+    my ($self, $key, $value) = @_;
+    my $metadata = $self->{ METADATA } ||= { };
+
+    return $metadata unless defined $key;
+
+    if (defined $value) {
+	$metadata->{ $key } = $value;
+    }
+    else {
+	$value = $self->{ METADATA }->{ $key };
+	return defined $value ? $value 
+	    : $self->error("no such metadata item: $key");
+    }
+}
+
+
 #------------------------------------------------------------------------
 # error()
 # error($msg, ...)
@@ -266,7 +298,7 @@ Pod::POM::Node - base class for a POM node
 
     %ATTRIBS =   ( indent => 4 );
     @ACCEPT  = qw( over item begin for text verbatim );
-    $EXPECT  = qw( back );
+    $EXPECT  =  q( back );
 
     package main;
     my $list = Pod::POM::Node::Over->new(8);
@@ -395,7 +427,7 @@ successful termination.
 
     %ATTRIBS =   ( indent => 4 );
     @ACCEPT  = qw( over item begin for text verbatim );
-    $EXPECT  = qw( back );
+    $EXPECT  =  q( back );
 
     package main;
     my $list = Pod::POM::Node::Over->new();
@@ -446,7 +478,7 @@ The present() method is used to present a node through a particular view.
 This simply maps the node type to a method which is then called against the 
 view object.  This is known as 'double dispatch'.
 
-    my $view = Pod::POM::View::HTML;
+    my $view = 'Pod::POM::View::HTML';
     print $list->present($view);
 
 The method name is constructed from the node type prefixed by 'view_'.  
